TokioExecution

Struct TokioExecution 

pub struct TokioExecution<R, E> { /* private fields */ }
Future-backed execution returned by TokioExecutor.

This struct implements Future: Output is Result<R, E> — the success value R or the callable’s error E. Await this type (on a Tokio-driven async context) to receive that result; until then the underlying blocking task may still be running.

Tokio join errors are not part of that Result: task panics are resumed and cancellations panic when the future is awaited.

Type Parameters

  • R - The task success value.
  • E - The task error value.

Implementations

Source

impl<R, E> TokioExecution<R, E>

pub fn is_finished(&self) -> bool

Returns whether the Tokio task has finished.

Returns

true if the underlying Tokio task has completed.

pub fn cancel(&self) -> bool

Requests cancellation of the underlying Tokio task.

Tokio can cancel a blocking task only before it starts. If the blocking closure is already running, this request is best-effort and awaiting the execution will still wait for the closure to finish.

Returns

true after the cancellation request has been sent to Tokio.